// Copyright (c) 1999,2003
// Utrecht University (The Netherlands),
// ETH Zurich (Switzerland),
// INRIA Sophia-Antipolis (France),
// Max-Planck-Institute Saarbruecken (Germany),
// and Tel-Aviv University (Israel).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org)
//
// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Kernel_23/include/CGAL/kernel_basic.h $
// $Id: include/CGAL/kernel_basic.h 08b27d3db14 $
// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Stefan Schirra

#ifndef CGAL_KERNEL_BASIC_H
#define CGAL_KERNEL_BASIC_H

#include <CGAL/kernel_config.h>

#include <CGAL/kernel_assertions.h>
#include <CGAL/enum.h>
#include <CGAL/aff_transformation_tags.h>
#include <CGAL/Object.h>
#include <CGAL/Kernel_traits.h>

#endif // CGAL_KERNEL_BASIC_H
